@@ -25,7 +25,6 @@
 #include <math.h>
 
 #include "gegl.h"
-#include "gegl-types-internal.h"
 #include "gegl-buffer-types.h"
 #include "gegl-buffer.h"
 #include "gegl-buffer-private.h"
@@ -137,8 +136,8 @@ gegl_sampler_init (GeglSampler *sampler)
   } while ( ++i<GEGL_SAMPLER_MIPMAP_LEVELS );
 
   sampler->level[0].sampler_buffer =
-    g_malloc0 (GEGL_SAMPLER_MAXIMUM_WIDTH *
-               GEGL_SAMPLER_MAXIMUM_HEIGHT * GEGL_SAMPLER_BPP);
+    g_malloc (GEGL_SAMPLER_MAXIMUM_WIDTH *
+              GEGL_SAMPLER_MAXIMUM_HEIGHT * GEGL_SAMPLER_BPP);
 }
 
 static void
@@ -243,115 +242,11 @@ dispose (GObject *gobject)
   /* This call handles unreffing the buffer and disconnecting signals */
   set_buffer (sampler, NULL);
 
+  g_clear_object (&sampler->point_sampler);
+
   G_OBJECT_CLASS (gegl_sampler_parent_class)->dispose (gobject);
 }
 
-GeglRectangle _gegl_sampler_compute_rectangle (GeglSampler *sampler,
-                                               gint         x,
-                                               gint         y,
-                                               gint         level_no)
-{
-  GeglRectangle rectangle;
-  GeglSamplerLevel *level = &sampler->level[level_no];
-
-  if (level->last_x || level->last_y)
-  {
-    gint x_delta = x - level->last_x;
-    gint y_delta = y - level->last_y;
-    gint max_delta_squared = 60 * 60;
-
-    if (x_delta * x_delta < max_delta_squared &&
-        y_delta * y_delta < max_delta_squared)
-    {
-      level->x_delta = level->x_delta * 0.99 + x_delta * 0.01;
-      level->y_delta = level->y_delta * 0.99 + y_delta * 0.01;
-      if (x_delta < 0) x_delta = -x_delta;
-      if (y_delta < 0) y_delta = -y_delta;
-      level->x_magnitude = level->x_magnitude  * 0.99 + x_delta * 0.01;
-      level->y_magnitude = level->y_magnitude  * 0.99 + y_delta * 0.01;
-    }
-  }
-  level->last_x = x;
-  level->last_y = y;
-
-  rectangle.width  = level->context_rect.width + 2;
-  rectangle.height = level->context_rect.height + 2;
-
-  rectangle.x = x + level->context_rect.x;
-  rectangle.y = y + level->context_rect.y;
-
-  /* grow area slightly, maybe getting a couple of extra
-     hits out of cour cache
-   */
-  rectangle.x      -= 2;
-  rectangle.y      -= 2;
-  rectangle.width  += 4;
-  rectangle.height += 4;
-
-#if 0
-  /* XXX: FIXME: grow cached area based on sampling pattern profiling
-   * information, possibly with much bigger wins than the marginal wins the
-   * increase in size by 2 in each dir does.
-   */
-
-
-  if (level->x_magnitude > 0.001 || level->y_magnitude > 0.001)
-    {
-      gfloat magnitude = sqrtf (level->x_magnitude * level->x_magnitude +
-                                level->y_magnitude * level->y_magnitude);
-      gfloat new_magnitude;
-
-      if (level->x_magnitude > level->y_magnitude)
-        new_magnitude =
-          4 + 60 * (level->x_magnitude - level->y_magnitude) / level->x_magnitude;
-      else
-        new_magnitude =
-          4 + 60 * (level->y_magnitude - level->x_magnitude) / level->y_magnitude;
-
-      rectangle.width = 
-        (level->x_magnitude / magnitude) * new_magnitude
-        + level->context_rect.width + 2;
-      rectangle.height = 
-        (level->y_magnitude / magnitude) * new_magnitude
-        + level->context_rect.height + 2;
-
-      /* todo: if both xmag and ymag are small - but similar in magnitude 
-         we should increase the size of the cache if it would fit, thus
-         perhaps working better on small local non-linear access patterns
-       */
-
-
-      /* align rectangle corner we've likely entered with sampled pixel
-       */
-      if (level->x_delta >=0)
-        rectangle.x = x + level->context_rect.x
-                        - (rectangle.width - level->context_rect.x)/10;
-      else
-        rectangle.x = x + level->context_rect.x
-                        - (rectangle.width - level->context_rect.width) * 9/10;
-
-      if (level->y_delta >=0)
-        rectangle.y = y + level->context_rect.y
-                        - (rectangle.height - level->context_rect.y)/10;
-      else
-        rectangle.y = y + level->context_rect.y 
-                        - (rectangle.height - level->context_rect.height) * 9/10;
-    }
-#endif
-
-  if (rectangle.width >= GEGL_SAMPLER_MAXIMUM_WIDTH)
-    rectangle.width = GEGL_SAMPLER_MAXIMUM_WIDTH;
-  if (rectangle.height >= GEGL_SAMPLER_MAXIMUM_HEIGHT)
-    rectangle.height = GEGL_SAMPLER_MAXIMUM_HEIGHT;
-
-  if (rectangle.width < level->context_rect.width)
-    rectangle.width = level->context_rect.width;
-  if (rectangle.height < level->context_rect.height)
-    rectangle.height = level->context_rect.height;
-
-  return rectangle;
-}
-
 
 gfloat *
 gegl_sampler_get_from_mipmap (GeglSampler    *sampler,
@@ -397,7 +292,7 @@ gegl_sampler_get_from_mipmap (GeglSampler    *sampler,
                                                                   level_no);
       if (!level->sampler_buffer)
         level->sampler_buffer =
-          g_malloc0 (GEGL_SAMPLER_ROWSTRIDE * GEGL_SAMPLER_MAXIMUM_HEIGHT);
+          g_malloc (GEGL_SAMPLER_ROWSTRIDE * GEGL_SAMPLER_MAXIMUM_HEIGHT);
 
       gegl_buffer_get (sampler->buffer,
                        &level->sampler_rectangle,
@@ -562,7 +457,8 @@ gegl_buffer_sample_at_level (GeglBuffer       *buffer,
 
       if (buffer->sampler)
       {
-        g_clear_object (&buffer->sampler);
+        g_object_unref (buffer->sampler);
+        buffer->sampler = NULL;
         buffer->sampler_type = 0;
       }
 
@@ -611,7 +507,11 @@ gegl_buffer_sample_cleanup (GeglBuffer *buffer)
   if (threaded)
     g_mutex_lock (&gegl_buffer_sampler_mutex);
 
-  g_clear_object (&buffer->sampler);
+  if (buffer->sampler)
+    {
+      g_object_unref (buffer->sampler);
+      buffer->sampler = NULL;
+    }
 
   if (threaded)
     g_mutex_unlock (&gegl_buffer_sampler_mutex);
