@@ -29,12 +29,10 @@
 
 G_BEGIN_DECLS
 
-#define GEGL_TYPE_OPERATION            (gegl_operation_get_type ())
-#define GEGL_OPERATION(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEGL_TYPE_OPERATION, GeglOperation))
 #define GEGL_OPERATION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  GEGL_TYPE_OPERATION, GeglOperationClass))
-#define GEGL_IS_OPERATION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEGL_TYPE_OPERATION))
 #define GEGL_IS_OPERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  GEGL_TYPE_OPERATION))
 #define GEGL_OPERATION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  GEGL_TYPE_OPERATION, GeglOperationClass))
+/* The rest is in gegl-types.h */
 
 typedef struct _GeglOperationClass GeglOperationClass;
 
@@ -71,15 +69,25 @@ struct _GeglOperationClass
   GObjectClass    parent_class;
 
   const gchar    *name;        /* name(string) used to create/identify
-                                  this type of operation in GEGL, should be
+                                  this type of operation in GEGL, must be
                                   set through gegl_operation_class_set_key(s) */
   const gchar    *compat_name; /* allows specifying an alias that the op is
-                                  also known as */
+                                  also known as, must be set through
+                                  gegl_operation_class_set_key(s) */
   GHashTable     *keys;        /* hashtable used for storing meta-data about an op */
 
   guint           no_cache      :1;  /* do not create a cache for this operation */
   guint           opencl_support:1;
-  guint64         bit_pad:62;
+  guint           want_in_place:1; /* if possible to use for in-place
+                                      processing, making output buffer =
+                                      input buffer.
+                                      */
+  guint           threaded:1;  /* do threaded processing if possible,
+                                  some base classes have special logic
+                                  to accelerate rendering; this allows opting in/out
+                                  in the sub-classes of these.
+                                */
+  guint64         bit_pad:60;
 
   /* attach this operation with a GeglNode, override this if you are creating a
    * GeglGraph, it is already defined for Filters/Sources/Composers.
@@ -146,10 +154,6 @@ struct _GeglOperationClass
   gpointer      pad[9];
 };
 
-
-
-GType           gegl_operation_get_type        (void) G_GNUC_CONST;
-
 GeglRectangle   gegl_operation_get_invalidated_by_change
                                              (GeglOperation *operation,
                                               const gchar   *input_pad,
@@ -221,9 +225,6 @@ const Babl  * gegl_operation_get_source_format (GeglOperation *operation,
 GeglNode    * gegl_operation_get_source_node   (GeglOperation *operation,
                                                 const gchar   *pad_name);
 
-GParamSpec ** gegl_operation_list_properties   (const gchar *operation_type,
-                                                guint       *n_properties_p);
-
 /* API to change  */
 void          gegl_operation_class_set_key     (GeglOperationClass *klass,
                                                 const gchar *key_name,
@@ -236,17 +237,19 @@ void          gegl_operation_class_set_keys    (GeglOperationClass *klass,
                                                 const gchar        *key_name,
                                                 ...);
 
-gchar      ** gegl_operation_list_keys         (const gchar *operation_type,
-                                                guint       *n_keys);
 
 void          gegl_operation_set_key           (const gchar *operation_type,
                                                 const gchar *key_name,
                                                 const gchar *key_value);
 
-const gchar * gegl_operation_get_key            (const gchar *operation_type,
-                                                 const gchar *key_name);
 
-/* invalidate a specific rectangle, indicating the any computation depending
+gboolean      gegl_operation_use_opencl         (const GeglOperation *operation);
+
+gboolean
+gegl_operation_use_threading (GeglOperation *operation,
+                              const GeglRectangle *roi);
+
+/* Invalidate a specific rectangle, indicating the any computation depending
  * on this roi is now invalid.
  *
  * @roi : the region to blank or NULL for the nodes current have_rect
@@ -263,11 +266,38 @@ gboolean gegl_operation_cl_set_kernel_args (GeglOperation *operation,
 
 /* internal utility functions used by gegl, these should not be used
  * externally */
-gboolean gegl_operation_calc_need_rects      (GeglOperation       *operation,
-                                              gpointer             context_id);
 gboolean gegl_can_do_inplace_processing      (GeglOperation       *operation,
                                               GeglBuffer          *input,
                                               const GeglRectangle *result);
+
+/**
+ * gegl_object_set_has_forked: (skip)
+ * @object: Object to mark
+ *
+ * Mark an object as "forked", indicating that it should not be modified
+ * in place by gegl operations. This should only be used inside of the
+ * process method of a GeglOperation subclass.
+ */
+void     gegl_object_set_has_forked       (GObject *object);
+
+/**
+ * gegl_object_get_has_forked: (skip)
+ * @object: Object to check
+ *
+ * Returns TRUE if the object has been marked as "forked".
+ */
+gboolean  gegl_object_get_has_forked      (GObject *object);
+
+/**
+ * gegl_temp_buffer:
+ *
+ * Returns a singleton scratch buffer for use with multi-threaded processing
+ * dispatch.
+ */
+guchar    *gegl_temp_buffer (int no, int min_size);
+
+void       gegl_operation_progress (GeglOperation *operation, gdouble progress, gchar *message);
+
 G_END_DECLS
 
 /***
